summaryrefslogtreecommitdiff
path: root/src/mongo/s/cluster_last_error_info.h
diff options
context:
space:
mode:
authorAdam Midvidy <amidvidy@gmail.com>2015-06-10 09:04:01 -0400
committerAdam Midvidy <amidvidy@gmail.com>2015-06-16 16:25:38 -0400
commit2bf407c955f383a29d3d10fc6be273d9c6890961 (patch)
tree31fd0be5d44d1fff9fae387cc37ad5f9c82e544e /src/mongo/s/cluster_last_error_info.h
parentb6b9e3ecd726bf9c36155e2dccd67f825a95800c (diff)
downloadmongo-2bf407c955f383a29d3d10fc6be273d9c6890961.tar.gz
SERVER-18236 send GLEStats over OP_COMMAND metadata object
Diffstat (limited to 'src/mongo/s/cluster_last_error_info.h')
-rw-r--r--src/mongo/s/cluster_last_error_info.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mongo/s/cluster_last_error_info.h b/src/mongo/s/cluster_last_error_info.h
index e68724d78f2..a3110e3d40b 100644
--- a/src/mongo/s/cluster_last_error_info.h
+++ b/src/mongo/s/cluster_last_error_info.h
@@ -95,8 +95,8 @@ namespace mongo {
};
/**
* Looks for $gleStats in a command response, and fills in the ClusterLastErrorInfo for this
* thread's associated Client with the data, if found.
*
* This data will be used by subsequent GLE calls, to ensure we look for the correct
* write on the correct PRIMARY.
@@ -104,6 +104,6 @@ namespace mongo {
* conn: the std::string name of the hostAndPort where the command ran. This can be a replica
* set seed list.
*/
- void saveGLEStats(const BSONObj& result, const std::string& conn);
+ void saveGLEStats(const BSONObj& metadataObj, StringData conn);
} // namespace mongo
@@ -95,8 +95,8 @@ namespace mongo {
};
/**
- * Looks for $gleStats in a command response, and fills in the ClusterLastErrorInfo for this
- * thread's associated Client with the data, if found.
+ * Looks for $gleStats in a command's reply metadata, and fills in the ClusterLastErrorInfo
+ * for this thread's associated Client with the data, if found.
*
* This data will be used by subsequent GLE calls, to ensure we look for the correct